@@ -40,9 +40,10 @@ project = u'zun-tempest-plugin'
 copyright = u'2017, OpenStack Developers'
 
 # openstackdocstheme options
-repository_name = 'openstack/zun-tempest-plugin'
-bug_project = 'zun'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/zun-tempest-plugin'
+openstackdocs_auto_name = False
+openstackdocs_bug_project = 'zun'
+openstackdocs_bug_tag = ''
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -52,7 +53,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
